@@ -44,7 +44,7 @@ from update_checker import update_check
 from warnings import simplefilter, warn, warn_explicit
 
 
-__version__ = '2.1.2'
+__version__ = '2.1.3'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -128,11 +128,12 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'spam':                'r/%s/about/spam/',
                  'stylesheet':          'r/%s/about/stylesheet/',
                  'submit':              'api/submit/',
+                 'sub_comments_gilded': 'r/%s/comments/gilded/',
                  'subreddit':           'r/%s/',
                  'subreddit_about':     'r/%s/about/',
                  'subreddit_comments':  'r/%s/comments/',
-                 'sub_comments_gilded': 'r/%s/comments/gilded/',
                  'subreddit_css':       'api/subreddit_stylesheet/',
+                 'subreddit_random':    'r/%s/random/',
                  'subreddit_settings':  'r/%s/about/edit/',
                  'subscribe':           'api/subscribe/',
                  'top':                 'top/',
@@ -606,6 +607,10 @@ class UnauthenticatedReddit(BaseReddit):
 
     """
 
+    def __init__(self, *args, **kwargs):
+        super(UnauthenticatedReddit, self).__init__(*args, **kwargs)
+        self._random_count = 0
+
     @decorators.require_captcha
     def create_redditor(self, user_name, password, email='', captcha=None):
         """Register a new user.
@@ -808,6 +813,22 @@ class UnauthenticatedReddit(BaseReddit):
                                  raw_response=True)
         return self.get_subreddit(response.url.rsplit('/', 2)[-2])
 
+    def get_random_submission(self, subreddit='all'):
+        """Return a random Submission object.
+
+        :param subreddit: Limit the submission to the specified
+            subreddit(s). Default: all
+
+        """
+        url = self.config['subreddit_random'] % six.text_type(subreddit)
+        try:
+            self._request(url, params={'unique': self._random_count},
+                          raw_response=True)
+        except errors.RedirectException as exc:  # This _should_ occur
+            self._random_count += 1  # Avoid network-level caching
+            return self.get_submission(exc.response_url)
+        raise errors.ClientException('Expected exception not raised.')
+
     def get_redditor(self, user_name, *args, **kwargs):
         """Return a Redditor instance for the user_name specified.
 
